
#ifndef _C13_re631_
#define _C13_re631_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F562_2675(EIF_REFERENCE);
extern void EIF_Minit631(void);
extern EIF_INTEGER_32 F638_3141(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
